package com.ruoyi.hezhi.service;

import com.ruoyi.hezhi.domain.TbNotice;
import com.ruoyi.hezhi.domain.vo.NoticeVO;

import java.util.List;
import java.util.Map;

/**
 * 通知公告Service接口
 *
 * @author ruoyi
 * @date 2024-09-14
 */
public interface ITbNoticeService
{
    /**
     * 查询通知公告
     *
     * @param noticeId 通知公告主键
     * @return 通知公告
     */
    public TbNotice selectTbNoticeByNoticeId(Long noticeId);

    /**
     * 查询通知公告列表
     *
     * @param tbNotice 通知公告
     * @return 通知公告集合
     */
    public List<TbNotice> selectTbNoticeList(TbNotice tbNotice);

    /**
     * 新增通知公告
     *
     * @param tbNotice 通知公告
     * @return 结果
     */
    public int insertTbNotice(TbNotice tbNotice);

    /**
     * 修改通知公告
     *
     * @param tbNotice 通知公告
     * @return 结果
     */
    public int updateTbNotice(TbNotice tbNotice);

    /**
     * 批量删除通知公告
     *
     * @param noticeIds 需要删除的通知公告主键集合
     * @return 结果
     */
    public int deleteTbNoticeByNoticeIds(Long[] noticeIds);

    /**
     * 删除通知公告信息
     *
     * @param noticeId 通知公告主键
     * @return 结果
     */
    public int deleteTbNoticeByNoticeId(Long noticeId);

    /**
     * 获取公告列表
     * @return
     */
    public List<NoticeVO> getNoticeList();

    /**
     * 查询公告列表
     *
     * @param params 参数
     * @return 公告列表
     */
    public List<Map<String, Object>> getPCNoticeList(Map<String, Object> params);

    /**
     * 查询公告详情
     *
     * @param params 参数
     * @return 公告列表
     */
    public Map<String, Object> getNoticeInfo(Map<String, Object> params);

    /**
     * 浏览量+1
     *
     * @param noticeId 通知公告主键
     * @return 结果
     */
    public int addViewsNum(Long noticeId);

    /**
     * 获取详情
     * @param id
     * @return
     */
    public NoticeVO getDetail(Long id);
}
